@@ -870,9 +870,11 @@ class VariableClBuilderImage(ReadonlyVariable):
         image_name = self.Get('cl_builder_image_filename')
         bdn = self.Get('cl_builder_iso_path')
         exclude_list = self.Get('cl_builder_squash_exclude')
+        include_list = self.Get('cl_builder_video_ebuilds')
         iso = distr.IsoDistributive(image_name, bdirectory=bdn,
                                     vol_id=self.Get('cl_builder_iso_label'),
                                     exclude=exclude_list,
+                                    include=include_list,
                                     compress=self.Get('cl_builder_compress'))
         return iso
 
@@ -1276,6 +1278,12 @@ class VariableClBuilderKeepTreeSet(Variable):
         self.help = _("keep portage tree in image")
         self.label = _("Keep portage tree")
 
+class VariableClBuilderVideoEbuilds(Variable):
+    """
+    Переменная заполняемая при выполнении задачи утилиты
+    """
+    type = "list"
+    value = []
 
 class VariableClBuilderSquashExclude(ReadonlyVariable):
     """
@@ -1288,8 +1296,9 @@ class VariableClBuilderSquashExclude(ReadonlyVariable):
         keep_tree = self.GetBool('cl_builder_keep_tree_set')
         excludes = ["", "metadata"]
         important = ["distfiles", "packages", "eclass", "metadata",
-                     "profiles", "layout.conf"]
+                     "profiles", "layout.conf"] 
         exclude_dirs = ["profiles/templates/deprecated", "profiles/updates"]
+        important_files = self.Get('cl_builder_video_ebuilds')
 
         def generator():
             for rep_dn in self.Get('cl_builder_repository_location'):
